@@ -8,6 +8,7 @@ use base qw(Net::Amazon);
 
 use Net::Amazon::Property::Book;
 use Net::Amazon::Property::CE;
+use Net::Amazon::Property::DigitalMusicTrack;
 use Net::Amazon::Property::DVD;
 use Net::Amazon::Property::Music;
 use Net::Amazon::Property::Software;
@@ -51,6 +52,7 @@ our %DEFAULT_ATTRIBUTES_XPATH = (
     RawListPrice => [qw(ItemAttributes ListPrice Amount)],
     CurrencyCode => [qw(ItemAttributes ListPrice CurrencyCode)],
     ReleaseDate => [qw(ItemAttributes ReleaseDate)],
+    SimilarProducts => [qw(SimilarProducts SimilarProduct)],
 );
 
 our @DEFAULT_ATTRIBUTES = qw(
@@ -180,7 +182,7 @@ sub factory {
     my $obj;
 
     if(0) {
-    } elsif($catalog eq "Book") {
+    } elsif($catalog eq "Book" || $catalog eq "eBooks") {
         DEBUG("Creating new Book Property");
         $obj = Net::Amazon::Property::Book->new(xmlref => $xmlref);
     } elsif($catalog eq "Music") {
@@ -198,6 +200,9 @@ sub factory {
     } elsif($catalog eq "CE") { # Consumer Electronics?
         DEBUG("Creating new CE Property");
         $obj = Net::Amazon::Property::CE->new(xmlref => $xmlref);
+    } elsif($catalog eq "Digital Music Track") {
+	DEBUG("Creating new Digital Music Track");
+	$obj = Net::Amazon::Property::DigitalMusicTrack->new(xmlref => $xmlref);
     } else {
 #         print "UNKNOWN CATALOG: ", Data::Dumper::Dumper($xmlref), "\n";
 #         die "%Error: there is no property defined for type '$catalog'\n";
@@ -432,6 +437,10 @@ Returns a list of browse nodes (text string categories) for this item.
 
 Returns a list of ASINs of similar items for this item.
 
+=item SimilarProducts()
+
+Returns a list of ASINs and titles of similar items for this item.
+
 =back
 
 Please check the subclasses of C<Net::Amazon::Property> for specialized 
